@@ -26,6 +26,8 @@
 #include <QtCore/QSharedPointer>
 #include <qbasicatomic.h>
 
+#include "kcoreaddons_debug.h"
+
 #include <unistd.h> // Check for sched_yield
 #include <sched.h>  // sched_yield
 #include <errno.h>
@@ -76,6 +78,10 @@
 #if defined(_POSIX_ADVISORY_INFO) && ((_POSIX_ADVISORY_INFO == 0) || (_POSIX_ADVISORY_INFO >= 200112L))
 #define KSDC_POSIX_FALLOCATE_SUPPORTED 1
 #endif
+#ifdef Q_OS_OSX
+#include "posix_fallocate_mac.h"
+#define KSDC_POSIX_FALLOCATE_SUPPORTED 1
+#endif
 
 // BSD/Mac OS X compat
 #if HAVE_SYS_MMAN_H
@@ -204,7 +210,7 @@ public:
         }
 
         // Attempt to setup for thread-only synchronization.
-        if (!processSharingSupported && pthread_mutex_init(&m_mutex, NULL) != 0) {
+        if (!processSharingSupported && pthread_mutex_init(&m_mutex, nullptr) != 0) {
             return false;
         }
 
@@ -242,7 +248,7 @@ public:
         // Long timeout, but if we fail to meet this timeout it's probably a cache
         // corruption (and if we take 8 seconds then it should be much much quicker
         // the next time anyways since we'd be paged back in from disk)
-        timeout.tv_sec = 10 + ::time(NULL); // Absolute time, so 10 seconds from now
+        timeout.tv_sec = 10 + ::time(nullptr); // Absolute time, so 10 seconds from now
         timeout.tv_nsec = 0;
 
         return pthread_mutex_timedlock(&m_mutex, &timeout) == 0;
@@ -309,7 +315,7 @@ public:
         // Long timeout, but if we fail to meet this timeout it's probably a cache
         // corruption (and if we take 8 seconds then it should be much much quicker
         // the next time anyways since we'd be paged back in from disk)
-        timeout.tv_sec = 10 + ::time(NULL); // Absolute time, so 10 seconds from now
+        timeout.tv_sec = 10 + ::time(nullptr); // Absolute time, so 10 seconds from now
         timeout.tv_nsec = 0;
 
         return sem_timedwait(&m_semaphore, &timeout) == 0;
@@ -373,7 +379,7 @@ static SharedLockId findBestSharedLock()
 #ifdef KSDC_THREAD_PROCESS_SHARED_SUPPORTED
     {
         pthread_mutex_t tempMutex;
-        QSharedPointer<KSDCLock> tempLock(0);
+        QSharedPointer<KSDCLock> tempLock(nullptr);
         if (timeoutsSupported) {
 #ifdef KSDC_TIMEOUTS_SUPPORTED
             tempLock = QSharedPointer<KSDCLock>(new pthreadTimedLock(tempMutex));
@@ -394,7 +400,7 @@ static SharedLockId findBestSharedLock()
 #ifdef KSDC_SEMAPHORES_SUPPORTED
     {
         sem_t tempSemaphore;
-        QSharedPointer<KSDCLock> tempLock(0);
+        QSharedPointer<KSDCLock> tempLock(nullptr);
         if (timeoutsSupported) {
             tempLock = QSharedPointer<KSDCLock>(new semaphoreTimedLock(tempSemaphore));
         } else {
@@ -476,7 +482,7 @@ static bool ensureFileAllocated(int fd, size_t fileSize)
 #ifdef __GNUC__
 #warning "This system does not seem to support posix_fallocate, which is needed to ensure KSharedDataCache's underlying files are fully committed to disk to avoid crashes with low disk space."
 #endif
-    qWarning() << "This system misses support for posix_fallocate()"
+    qCWarning(KCOREADDONS_DEBUG) << "This system misses support for posix_fallocate()"
                " -- ensure this partition has room for at least"
                << fileSize << "bytes.";
 
